pub struct GetTableMetadataFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetTableMetadata.
Returns table metadata for the specified catalog, database, and table.
Implementations
Sourceimpl GetTableMetadataFluentBuilder
impl GetTableMetadataFluentBuilder
Sourcepub fn as_input(&self) -> &GetTableMetadataInputBuilder
pub fn as_input(&self) -> &GetTableMetadataInputBuilder
Access the GetTableMetadata as a reference.
Sourcepub async fn send(
self,
) -> Result<GetTableMetadataOutput, SdkError<GetTableMetadataError, HttpResponse>>
pub async fn send( self, ) -> Result<GetTableMetadataOutput, SdkError<GetTableMetadataError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetTableMetadataOutput, GetTableMetadataError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetTableMetadataOutput, GetTableMetadataError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn catalog_name(self, input: impl Into<String>) -> Self
pub fn catalog_name(self, input: impl Into<String>) -> Self
The name of the data catalog that contains the database and table metadata to return.
Sourcepub fn set_catalog_name(self, input: Option<String>) -> Self
pub fn set_catalog_name(self, input: Option<String>) -> Self
The name of the data catalog that contains the database and table metadata to return.
Sourcepub fn get_catalog_name(&self) -> &Option<String>
pub fn get_catalog_name(&self) -> &Option<String>
The name of the data catalog that contains the database and table metadata to return.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database that contains the table metadata to return.
Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database that contains the table metadata to return.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database that contains the table metadata to return.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which metadata is returned.
Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which metadata is returned.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which metadata is returned.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.