#[non_exhaustive]pub struct GetTableMetadataInputBuilder { /* private fields */ }Expand description
A builder for GetTableMetadataInput.
Implementations
Sourceimpl GetTableMetadataInputBuilder
impl GetTableMetadataInputBuilder
Sourcepub fn catalog_name(self, input: impl Into<String>) -> Self
pub fn catalog_name(self, input: impl Into<String>) -> Self
The name of the data catalog that contains the database and table metadata to return.
This field is required.Sourcepub fn set_catalog_name(self, input: Option<String>) -> Self
pub fn set_catalog_name(self, input: Option<String>) -> Self
The name of the data catalog that contains the database and table metadata to return.
Sourcepub fn get_catalog_name(&self) -> &Option<String>
pub fn get_catalog_name(&self) -> &Option<String>
The name of the data catalog that contains the database and table metadata to return.
Sourcepub fn database_name(self, input: impl Into<String>) -> Self
pub fn database_name(self, input: impl Into<String>) -> Self
The name of the database that contains the table metadata to return.
This field is required.Sourcepub fn set_database_name(self, input: Option<String>) -> Self
pub fn set_database_name(self, input: Option<String>) -> Self
The name of the database that contains the table metadata to return.
Sourcepub fn get_database_name(&self) -> &Option<String>
pub fn get_database_name(&self) -> &Option<String>
The name of the database that contains the table metadata to return.
Sourcepub fn table_name(self, input: impl Into<String>) -> Self
pub fn table_name(self, input: impl Into<String>) -> Self
The name of the table for which metadata is returned.
This field is required.Sourcepub fn set_table_name(self, input: Option<String>) -> Self
pub fn set_table_name(self, input: Option<String>) -> Self
The name of the table for which metadata is returned.
Sourcepub fn get_table_name(&self) -> &Option<String>
pub fn get_table_name(&self) -> &Option<String>
The name of the table for which metadata is returned.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup for which the metadata is being fetched. Required if requesting an IAM Identity Center enabled Glue Data Catalog.
Sourcepub fn build(self) -> Result<GetTableMetadataInput, BuildError>
pub fn build(self) -> Result<GetTableMetadataInput, BuildError>
Consumes the builder and constructs a GetTableMetadataInput.
Sourceimpl GetTableMetadataInputBuilder
impl GetTableMetadataInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<GetTableMetadataOutput, SdkError<GetTableMetadataError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<GetTableMetadataOutput, SdkError<GetTableMetadataError, HttpResponse>>
Sends a request with this input using the given client.